==> svm-1.0.0-rc16-sources.jar: com/oracle/svm/core/jdk8/zipfile/ZipFileUtil.java <==
/*
 * Copyright (c) 2018, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.jdk8.zipfile;

import com.oracle.svm.core.snippets.KnownIntrinsics;

// Checkstyle: stop
import sun.misc.JavaUtilZipFileAccess;
import sun.misc.PerfCounter;
import sun.misc.SharedSecrets;
// Checkstyle: resume

final class ZipFileUtil {

    static void setJavaUtilZipFileAccess() {
        SharedSecrets.setJavaUtilZipFileAccess(
                        // SVM start
                        new JavaUtilZipFileAccess() {
                            @Override
                            public boolean startsWithLocHeader(java.util.zip.ZipFile zip) {
                                return KnownIntrinsics.unsafeCast(zip, ZipFile.class).zsrc.startsWithLoc;
                            }
                            // public String[] getMetaInfEntryNames(ZipFile zip) {
                            // return zip.getMetaInfEntryNames();
                            // }
                        });
    }

    static void updateZipFileCounters(long startZipFileOpen) {
        PerfCounter.getZipFileOpenTime().addElapsedTimeFrom(startZipFileOpen);
        PerfCounter.getZipFileCount().increment();
    }
}

==> svm-20.1.0-sources.jar: com/oracle/svm/core/jdk8/zipfile/ZipFileUtil.java <==
/*
 * Copyright (c) 2018, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.jdk8.zipfile;

import com.oracle.svm.core.SubstrateUtil;
// Checkstyle: stop
import sun.misc.JavaUtilZipFileAccess;
import sun.misc.PerfCounter;
import sun.misc.SharedSecrets;
// Checkstyle: resume

final class ZipFileUtil {

    static void setJavaUtilZipFileAccess() {
        SharedSecrets.setJavaUtilZipFileAccess(
                        // SVM start
                        new JavaUtilZipFileAccess() {
                            @Override
                            public boolean startsWithLocHeader(java.util.zip.ZipFile zip) {
                                return SubstrateUtil.cast(zip, ZipFile.class).zsrc.startsWithLoc;
                            }
                            // public String[] getMetaInfEntryNames(ZipFile zip) {
                            // return zip.getMetaInfEntryNames();
                            // }
                        });
    }

    static void updateZipFileCounters(long startZipFileOpen) {
        PerfCounter.getZipFileOpenTime().addElapsedTimeFrom(startZipFileOpen);
        PerfCounter.getZipFileCount().increment();
    }
}
